@@ -226,8 +226,18 @@ Assicurati che &apos;xsettingsd&apos; sia installato per aiutare le applicazioni
     </message>
     <message>
         <location filename="../lxqtthemeconfig.ui" line="57"/>
-        <source>Override user-defined wallpaper</source>
-        <translation>Sostituisci sfondo desktop personalizzato</translation>
+        <source>Use wallpaper provided by theme</source>
+        <translation>Usa sfondo desktop del tema</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="94"/>
+        <source>(User Theme)</source>
+        <translation>(Tema locale)</translation>
+    </message>
+    <message>
+        <location filename="../lxqtthemeconfig.cpp" line="182"/>
+        <source>Open theme folder</source>
+        <translation>Apri cartella del tema</translation>
     </message>
 </context>
 <context>
