@@ -33,7 +33,7 @@
     <name>LoadSettings</name>
     <message>
         <location filename="../loadsettings.cpp" line="98"/>
-        <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
+        <source>Default monitor settings have been applied. Use lxqt-config-monitor for adjusting your monitor settings.</source>
         <translation>הגדרות ברירת המחדל לצגים הוחלו. אם ברצונך לשנות את ההגדרות לצגים, נא להשתמש ב־lxqt-config-monitor.</translation>
     </message>
 </context>
@@ -311,7 +311,7 @@
         <source>%n second(s) remaining</source>
         <translation>
             <numerusform>נותרה שנייה אחת</numerusform>
-            <numerusform>נותרו %n שניות</numerusform>
+            <numerusform>נותרו שתי שניות</numerusform>
         </translation>
     </message>
 </context>
