@@ -33,7 +33,7 @@
     <name>LoadSettings</name>
     <message>
         <location filename="../loadsettings.cpp" line="98"/>
-        <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
+        <source>Default monitor settings have been applied. Use lxqt-config-monitor for adjusting your monitor settings.</source>
         <translation>Standardskärmsinställningarna har tillämpats. Om du vill ändra inställningar för bildskärmar, använd lxqt-config-monitor.</translation>
     </message>
 </context>
@@ -193,7 +193,7 @@
     <message>
         <location filename="../monitorwidget.ui" line="153"/>
         <source>Rotation:</source>
-        <translation>Rotation:</translation>
+        <translation>Vridning:</translation>
     </message>
     <message>
         <location filename="../monitorwidget.ui" line="176"/>
